package com.docus.server.collection.webservice;

import javax.jws.WebService;

/**
 * @author Fang Ruichuan
 * @date 2022-11-14 19:03
 */

@WebService
public interface ReceiveServer {
    /**
     * 科室信息接收，进行操作
     *
     * @param receiveUser 接收到的科室数据
     * @return 返回结果
     */
    String deptModify(String receiveUser);

    String setTBasic(String str);

    String updateTBasic(String str);

    /**
     * @description新增入院基础数据
     */
    public String setAdmissTBasic(String message);

    /**
     * @description住院就诊更新基础数据
     */
    public String updateAdmissTBasic(String message);

    /**
     * 用户信息接收，进行操作
     *
     * @param receiveUser 接收到的用户参数
     * @return 返回结果
     */
    String userModify(String receiveUser);


    /**
     * 接收重症报告信息
     *
     * @param icuReportMessage 重症报告信息
     * @return 返回信息
     */
    String pushICUReport(String icuReportMessage);

    /**
     * 接收检验报告信息
     *
     * @param examinationReportMessage 检验报告信息
     * @return 返回信息
     */
    public String pushExaminationReport(String examinationReportMessage);

    /**
     * HIP1166-pdf件上传服务 顺德人医 ，和检查报告配合
     *
     * @param uploadMessage pdf上传信息
     * @return 成功或者异常信息
     */
    String pdfUpload(String uploadMessage);

    /**
     * 接收检查报告的信息 - 新增
     *
     * @param inspectionReportMessage 检查报告信息 - 新增
     * @return 成功或者异常信息
     */
    String pushAddInspectionReport(String inspectionReportMessage);

    /**
     * 接收检查报告的信息 - 更新
     *
     * @param inspectionReportMessage 检查报告信息 -更新
     * @return 成功或者异常信息
     */
    String pushUpdateInspectionReport(String inspectionReportMessage);

    /**
     * 接收检验报告的信息 新增
     *
     * @param laboratoryMessage 检验报告信息
     * @return 成功或者异常信息
     */
    String pushAddLaboratoryReport(String laboratoryMessage);


    /**
     * 接收检验报告的信息  更新
     *
     * @param laboratoryMessage 检验报告信息
     * @return 成功或者异常信息
     */
    String pushUpdateLaboratoryReport(String laboratoryMessage);


    /**
     * 接收检查报告的信息 - 更新
     *
     * @param xml 检查报告信息 -更新
     * @return 成功或者异常信息
     */
    String querySdJxIndexTest(String xml);

    String querySdJxIndexNoResultTest(String xml);

    /**
     * 母婴关系推送
     * @param maternalInfantRelationshipMessage 母婴关系消息
     * @return 成功或者异常信息
     */
    String pushMaternalInfantRelationship(String maternalInfantRelationshipMessage);
}
